@@ -100,6 +100,9 @@ sub _load_mapping {
     # load mapping from file
     my $mapping = LoadFile( $file );
     $self->{mapping} = $mapping->{$self->driver_dsn()} || {};
+
+    # remove stale entries
+    $self->_save_mapping( $file ) if $self->_check_mapping();
 }
 
 sub _save_mapping {
@@ -117,6 +120,22 @@ sub _save_mapping {
         or croak "Can't rename $file.tmp to $file: $!";
 }
 
+sub _check_mapping {
+    my ($self) = @_;
+    my $mapping = $self->{mapping};
+    my %database = map { $_ => undef } $self->databases();
+    my $updated;
+
+    # check that all databases in the mapping exist
+    for my $cwd ( keys %$mapping ) {
+        if ( !exists $database{ $mapping->{$cwd} } ) {
+            delete $mapping->{$cwd};
+            $updated++;
+        }
+    }
+    return $updated;
+}
+
 sub make_dsn {
     my ($self, @args, @pairs) = @_;
 
@@ -136,7 +155,7 @@ sub make_handle {
     my $dbname = $self->{mapping}{ cwd() };
 
     # if the database still exists, return it
-    if ( grep { $_ eq $dbname } $self->databases() ) {
+    if ( $dbname && grep { $_ eq $dbname } $self->databases() ) {
         $handle = Test::Database::Handle->new(
             dsn      => $self->dsn($dbname),
             username => $self->username(),
